@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Mon Mar 22 20:31:00 CST 2021"
+#define MP4V2_PROJECT_build           "Mon Jul 19 10:42:36 UTC 2021"
 
 /*****************************************************************************/
 
